@@ -40,14 +40,3 @@ fn test_serde_is_transparent() {
     let item = Item::new(42);
     assert_eq!(serde_json::to_string(&item).unwrap(), "42");
 }
-
-#[test]
-#[cfg(feature = "serde")]
-fn test_serde_idx_vec() {
-    use crate::IndexVec;
-
-    let idx_vec = IndexVec::<Bar, _>::from_raw(vec![1, 2, 3, 4, 5]);
-    assert_eq!(serde_json::to_string(&idx_vec).unwrap(), "[1,2,3,4,5]");
-
-    assert_eq!(serde_json::from_str::<IndexVec<Bar, usize>>("[1,2,3,4,5]").unwrap(), idx_vec);
-}
